"""Test the h5tester script."""

import os
import subprocess
from tempfile import NamedTemporaryFile
import unittest


load_page_set_window_status_returned = """\
    <html><head>
    <script type="text/javascript">
    window.status = '::::fnord';
    </script>
    </head><body></body></html>
    """

load_page_empty_return = """\
    <html><head>
    <script type="text/javascript">
    window.status = '::::';
    </script>
    </head><body></body></html>
    """

load_page_no_return = """\
    <html><head></head><body></body></html>
    """


class ScriptTestCase(unittest.TestCase):

    def setUp(self):
        self.file = NamedTemporaryFile(prefix='h5test_', suffix='.html')
        self.script = os.path.abspath(
            os.path.join(os.path.dirname(__file__), '..', 'h5tester'))

    def tearDown(self):
        self.file.close()

    def test_return_success(self):
        self.file.write(load_page_set_window_status_returned)
        self.file.flush()
        command = [self.script, self.file.name]
        browser = subprocess.Popen(
            command, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        content, ignore = browser.communicate()
        self.assertEqual(0, browser.returncode)
        self.assertEqual('fnord\n', content)

    def test_return_timeout(self):
        self.file.write(load_page_no_return)
        self.file.flush()
        command = [self.script, '-t', '100', self.file.name]
        browser = subprocess.Popen(
            command, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        content, ignore = browser.communicate()
        self.assertEqual(1, browser.returncode)
        self.assertEqual('', content)

    def test_return_nothing(self):
        self.file.write(load_page_empty_return)
        self.file.flush()
        command = [self.script, self.file.name]
        browser = subprocess.Popen(
            command, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        content, ignore = browser.communicate()
        self.assertEqual(2, browser.returncode)
        self.assertEqual('', content)
